@@ -5,8 +5,8 @@
 #' @param phi Estimated phi parameter by the iAR model.
 #' @param y Array with the time series observations.
 #' @param st Array with the irregular observational times.
-#' @param standarized logical; if true, the array y is standarized; if false, y contains the raw time series
-#' @param include.mean logical; if true, the array y has zero mean; if false, y has a mean different from zero.
+#' @param standardized logical; if TRUE, the array y is standardized; if FALSE, y contains the raw time series
+#' @param zero.mean logical; if TRUE, the array y has zero mean; if FALSE, y has a mean different from zero.
 #'
 #' @return Fitted values of the iAR model
 #' @export
@@ -23,17 +23,17 @@
 #' y<-y$series
 #' phi=IARloglik(y=y,st=st)$phi
 #' fit=IARfit(phi=phi,y=y,st=st)
-IARfit<-function(phi,y,st,standarized=T,include.mean=F)
+IARfit<-function(phi,y,st,standardized=TRUE,zero.mean=TRUE)
 {
   sigma = 1
   mu = 0
-  if (standarized == F)
+  if (standardized == FALSE)
     sigma = var(y)
-  if (include.mean == T)
+  if (zero.mean == TRUE)
     mu = mean(y)
-  if (include.mean == T)
+  if (zero.mean == TRUE)
     y = y-mu
-  if (standarized == F)
+  if (standardized == FALSE)
     y=y/sqrt(sigma)
   delta=diff(st)
   y1=y[-c(length(y))]
